import type { RouteLocationNamedRaw } from "vue-router";
import router from "@/js/router";
import type { Link } from "@/js/contexts/shared/models/Link";

export {};

declare global {
  interface Window {
    snowflake: string;
  }
}

declare module "@vue/runtime-core" {
  interface ComponentCustomProperties {
    $snowflake: SnowflakeProps & {
      router: {
        isCurrent: (route: RouteLocationNamedRaw) => boolean;
      };
    };
  }
}

export type SnowflakeProps = {
  app: {
    url: string;
    name: string;
  };
  appearance: {
    icon: string;
    background: string;
  };
  links: {
    homepage: boolean;
  };
  pages: {
    landing: {
      hero_title: string;
      hero_subtitle: string | null;
      link_shortening: boolean;
    };
  };
  seo: {
    home_title: string;
    title_template: string;
    title_separator: string;
    description: string | null;
    keywords: string | null;
  };
  authentication: {
    user_registration: boolean;
  };
  i18n: {
    locale: string;
    translations: { [key: string]: unknown[] };
  };
  demo: boolean;
  link?: Omit<Link, "id" | "user_id" | "domain_id" | "expires_at" | "visits_count" | "qr" | "favicon" | "short_url" | "created_at" | "updated_at">;
};

const props: SnowflakeProps = JSON.parse(atob(window.snowflake));

export default {
  install: (app: any) => {
    app.config.globalProperties.$snowflake = props;
    app.config.globalProperties.$snowflake.router = {
      isCurrent: (route: RouteLocationNamedRaw): boolean => router.currentRoute.value.matched.some(({ name }) => name === route.name),
    };
  },
};
